export declare class TreeNode {
    content: string;
    parent: TreeNode | null;
    children: TreeNode[];
    level: number;
    constructor(content: string, parent: TreeNode | null, children: TreeNode[], level: number);
    /**
     * Returns true if this node is the last child of its parent.
     * A root node is considered to be the last child.
     * This is used to determine the correct connector to use.
     */
    isLastChild(): boolean;
    /**
     * Returns the token to append before the content.
     */
    getPositionalToken(): string;
    /**
     * Determines the level of a line.
     * Every 2 spaces from the start of the line means 1 level.
     * The root node is level 0.
     */
    static levelize(line: string): number;
    /**
     * Returns formatted TreeNode content.
     * Removes dashes (-), asterisks (*), or plus signs (+) at the beginning of the line
     */
    static getContent(raw: string): string;
    /**
     * Creates TreeNode objects from the raw text.
     * @param raw - The raw text to parse.
     * @return The dummy root node of the tree.
     */
    static parse(raw: string): TreeNode;
    /**
     * Traverses the tree and appends the tokens to the given array.
     * @param currNode - The node to traverse.
     * @param result - The array to append the tokens to.
     */
    static traverse(currNode: TreeNode, result: string[]): void;
    /**
     * Returns the TreeNode as a string.
     * This assumes that the node is a root node.
     */
    toString(): string;
    /**
     * Returns the rendered tree.
     * @param raw - The raw text to parse.
     */
    static visualize(raw: string): string;
}
//# sourceMappingURL=tree.d.ts.map